==> 1.0.43+1.tar.gz: lib/components/UikContainerText.dart <==
import 'package:google_fonts/google_fonts.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikIconProps.dart';
import "package:flutter/material.dart";

import '../props/UikChipsProps.dart';
import '../props/UikContainerTextProps.dart';
import 'UikIcon.dart';
import 'UikWidget.dart';

class UikContainerText extends UikWidget {
  WidgetType _widgetType;
  UikContainerTextProps _uikContainerTextProps;
  UikContainerText(this._widgetType, this._uikContainerTextProps)
      : super(_widgetType, _uikContainerTextProps);

  @override
  _UikContainerTextState createState() =>
      _UikContainerTextState(_uikContainerTextProps);
}

class _UikContainerTextState extends State<UikContainerText> {
  UikContainerTextProps _uikContainerTextProps;
  _UikContainerTextState(this._uikContainerTextProps);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: (_uikContainerTextProps.isCenter == true)
          ? CrossAxisAlignment.center
          : CrossAxisAlignment.start,
      children: [
        Container(
          width: _uikContainerTextProps.width,
          height: _uikContainerTextProps.height,
          margin: EdgeInsets.fromLTRB(
              _uikContainerTextProps.leftMargin,
              _uikContainerTextProps.topMargin,
              _uikContainerTextProps.rightMargin,
              _uikContainerTextProps.bottomMargin),
          child: _uikContainerTextProps.isStrike
              ? Row(
                  children: [
                    Text(
                      "${_uikContainerTextProps.text} ",
                      //overflow: _uikContainerTextProps.,
                      style: GoogleFonts.getFont(
                        _uikContainerTextProps.fontFamily!,
                        fontSize: _uikContainerTextProps.size,
                        fontWeight: FontWeight.w400,
                        color: _uikContainerTextProps.color,
                        decoration: TextDecoration.none,
                      ),
                    ),
                    Text(
                      " ${_uikContainerTextProps.striketext}",
                      //overflow: _uikContainerTextProps.,
                      style: GoogleFonts.getFont(
                        _uikContainerTextProps.fontFamily!,
                        fontSize: _uikContainerTextProps.size,
                        fontWeight: FontWeight.w200,
                        color: _uikContainerTextProps.color,
                        decoration: TextDecoration.lineThrough,
                      ),
                    )
                  ],
                )
              : Text(
                  _uikContainerTextProps.text.toString(),
                  //overflow: _uikContainerTextProps.,
                  style: GoogleFonts.getFont(
                    _uikContainerTextProps.fontFamily!,
                    fontSize: _uikContainerTextProps.size,
                    fontWeight: _uikContainerTextProps.fontWeight,
                    color: _uikContainerTextProps.color,
                    decoration: TextDecoration.none,
                  ),
                ),
        ),
      ],
    );
  }
}

==> 1.0.69+1.tar.gz: lib/components/UikContainerText.dart <==
import 'package:google_fonts/google_fonts.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikIconProps.dart';
import "package:flutter/material.dart";

import '../props/UikChipsProps.dart';
import '../props/UikContainerTextProps.dart';
import 'UikIcon.dart';
import 'UikWidget.dart';

class UikContainerText extends UikWidget {
  WidgetType _widgetType;
  UikContainerTextProps _uikContainerTextProps;
  UikContainerText(this._widgetType, this._uikContainerTextProps)
      : super(_widgetType, _uikContainerTextProps);

  @override
  _UikContainerTextState createState() =>
      _UikContainerTextState(_uikContainerTextProps);
}

class _UikContainerTextState extends State<UikContainerText> {
  UikContainerTextProps _uikContainerTextProps;
  _UikContainerTextState(this._uikContainerTextProps);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: (_uikContainerTextProps.isCenter == true)
          ? CrossAxisAlignment.center
          : CrossAxisAlignment.start,
      children: [
        Container(
          width: _uikContainerTextProps.width,
          height: _uikContainerTextProps.height,
          margin: EdgeInsets.fromLTRB(
              _uikContainerTextProps.leftMargin,
              _uikContainerTextProps.topMargin,
              _uikContainerTextProps.rightMargin,
              _uikContainerTextProps.bottomMargin),
          child: _uikContainerTextProps.isStrike
              ? Row(
                  children: [
                    Text(
                      "${_uikContainerTextProps.text} ",
                      //overflow: _uikContainerTextProps.,
                      style: GoogleFonts.getFont(
                        _uikContainerTextProps.fontFamily,
                        fontSize: _uikContainerTextProps.size,
                        fontWeight: _uikContainerTextProps.normalFontWeight,
                        color: _uikContainerTextProps.color,
                        decoration: TextDecoration.none,
                      ),
                    ),
                    Text(
                      " ${_uikContainerTextProps.striketext}",
                      //overflow: _uikContainerTextProps.,
                      style: GoogleFonts.getFont(
                        _uikContainerTextProps.fontFamily,
                        fontSize: _uikContainerTextProps.size,
                        fontWeight: _uikContainerTextProps.strikenFontWeight,
                        color: _uikContainerTextProps.color,
                        decoration: TextDecoration.lineThrough,
                      ),
                    )
                  ],
                )
              : Text(
                  _uikContainerTextProps.text.toString(),
                  //overflow: _uikContainerTextProps.,
                  style: GoogleFonts.getFont(
                    _uikContainerTextProps.fontFamily,
                    fontSize: _uikContainerTextProps.size,
                    fontWeight: _uikContainerTextProps.normalFontWeight,
                    color: _uikContainerTextProps.color,
                    decoration: TextDecoration.none,
                  ),
                ),
        ),
      ],
    );
  }
}
